OC.L10N.register(
    "activity",
    {
    "Copied!" : "Копирано!",
    "Not supported!" : "Не се поддържа!",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
    "{name} (invisible)" : "{name} (невидим)",
    "{name} (restricted)" : "{name} (ограничен)",
    "Home" : "Начало",
    "in {path}" : "в {path}",
    "This stream will show events like additions, changes & shares" : "Потокът ще показва събития като допълнения, изменения и споделяния",
    "There are no events for this filter" : "Няма събития от този филтър",
    "Today" : "Днес",
    "Yesterday" : "Вчера",
    "Open {filename}" : "Отвори файл {filename}",
    "Activity" : "Активност",
    "Personal activity feed for %s" : "Поток за активността на %s",
    "Your feed URL is invalid" : "Емисията е с невалиден URL адрес",
    "Your settings have been updated." : "Вашите настройки са актуализирани.",
    "Settings have been updated." : "Настройките бяха актуализирани.",
    "Recent activity" : "Последна активност",
    "No activities" : "Няма активности",
    "More activities" : "Още активности",
    "Daily activity summary for %s" : "Обобщение на дневната активност за %s",
    "_and %n more _::_and %n more _" : ["и %n още ","и %n още "],
    "All activities" : "Всички активности",
    "By others" : "От други",
    "By you" : "От Вас",
    "Activity at %s" : "Дейност в %s",
    "Hello %s" : "Здравейте %s",
    "Hello %s," : "Здравейте %s,",
    "There was some activity at %s" : "Имаше събитие в %s",
    "Mail" : "Поща",
    "Push" : "Директно /push/",
    "Notifications" : "Известия",
    "This application enables people to view a log of activities about them, their files or other data." : "Това приложение позволява на хората да преглеждат журнал на активности, свързани с тях, техните файлове или други данни.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Това приложение позволява на хората да виждат действия, свързани с техните файлове и данни в Nextcloud.\n\t\tВсеки човек може да конфигурира индивидуални настройки на дейностите си в личните настройки,\n\t\tда избере кои дейности да се изпращат на мобилни телефони, като изпращането е по имейл\n\t\tили дали всяка сутрин да се изпраща дневно обобщение.\n\t\tПовече информация е налична в документацията за дейността.",
    "Activity notification configuration" : "Конфигурация на известие за активност",
    "Send email" : "Изпращане на имейл",
    "Send push notification" : "Изпращане на push известие",
    "You need to set up your email address before you can receive notification emails." : "Първо трябва да въведете вашия имейл адрес (в профила си), за да получавате известия.",
    "Send activity emails" : "Изпращане на имейли за активността",
    "As soon as possible" : "Възможно по-скоро",
    "Hourly" : "Всеки час",
    "Daily" : "Всеки ден",
    "Weekly" : "Всяка седмица",
    "No activity yet" : "Все още няма активност",
    "Notification" : "Известие",
    "Enable notification emails" : "Разрешаване на известяващи имейли",
    "Choose for which activities you want to get an email or push notification." : "Изберете за кои активности да получавате имейл или директно известие.",
    "Choose for which activities you want to get a push notification." : "Изберете за кои активности да получавате директно известие.",
    "Daily activity summary" : "Обобщение на дневната активност",
    "Send daily activity summary in the morning" : "Изпращане на дневно обобщение за активността сутрин.",
    "Default settings" : "Стандартни настройкки",
    "Configure the default notification settings for new accounts." : "Конфигуриране по подразбиране на настройките при известие за уведомяване за нови профили.",
    "Unable to save the settings" : "Настройките не могат да бъдат запазени",
    "Activity feed" : "Поток на активността",
    "Activity settings" : "Настройки за активност",
    "Enable RSS feed" : "Разрешаване на RSS емисии",
    "RSS feed" : "RSS емисия",
    "Copy RSS feed link" : "Копиране на връзка за RSS емисия",
    "Personal notification settings" : "Лични настройки за известие",
    "No more events to load" : "Няма повече известия за зареждане",
    "This application enables users to view a log of activities about them or about files." : "Това приложение позволява на потребителите да преглеждат журнал на техните активности или тази на файловете.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "Приложението позволява на потребителите да следят действия свързани с файловете им в  Nextcloud.\n\t\tСлед като се включи, потребителите ще видят елемент “Активност” , в менюто на приложения.\n\t\tПоказва действия свързани с файлове – създаване, изтриване, местене, преименуване.\n\t\tПотребителите могат да персонализират настройките на потока.\n\t\tТип на активност за показване и филтриране на собствените действия,\n\t\tда са достъпни само през браузър или да получават имейл известия.\n\t\tДопълнителна информация ще намерите в документацията на Activity.",
    "Unable to load the activity list" : "Неуспешно зареждане на списъкът с активности",
    "Activities" : "Активности /дейности/",
    "Configure the default notification settings for new users." : "Конфигуриране по подразбиране на известията за нови потребители."
},
"nplurals=2; plural=(n != 1);");
