OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Schlüsselpasswort zur Wiederherstellung fehlt",
    "Please repeat the recovery key password" : "Schlüsselpasswort zur Wiederherstellung bitte wiederholen",
    "Repeated recovery key password does not match the provided recovery key password" : "Das wiederholte Schlüsselpasswort zur Wiederherstellung stimmt nicht mit dem geforderten Schlüsselpasswort zur Wiederherstellung überein",
    "Recovery key successfully enabled" : "Der Wiederherstellungsschlüssel wurde erfolgreich aktiviert.",
    "Could not enable recovery key. Please check your recovery key password!" : "Der Wiederherstellungsschlüssel konnte nicht aktiviert werden. Bitte überprüfen Sie das Passwort für den Wiederherstellungsschlüssel!",
    "Recovery key successfully disabled" : "Der Wiederherstellungsschlüssel wurde erfolgreich deaktiviert.",
    "Could not disable recovery key. Please check your recovery key password!" : "Der Wiederherstellungsschlüssel konnte nicht deaktiviert werden. Bitte überprüfen Sie das Passwort für den Wiederherstellungsschlüssel!",
    "Missing parameters" : "Fehlende Parameter",
    "Please provide the old recovery password" : "Bitte das alte Wiederherstellungspasswort eingeben",
    "Please provide a new recovery password" : "Bitte ein neues Wiederherstellungspasswort eingeben",
    "Please repeat the new recovery password" : "Bitte das neue Passwort zur Wiederherstellung wiederholen",
    "Password successfully changed." : "Das Passwort wurde geändert.",
    "Could not change the password. Maybe the old password was not correct." : "Das Passwort konnte nicht geändert werden. Vielleicht war das alte Passwort falsch.",
    "Recovery Key disabled" : "Wiederherstellungsschlüssel deaktiviert",
    "Recovery Key enabled" : "Wiederherstellungsschlüssel aktiviert",
    "Could not enable the recovery key, please try again or contact your administrator" : "Der Wiederherstellungsschlüssel konnte nicht aktiviert werden, bitte versuchen Sie es noch einmal oder kontaktieren Sie Ihre Administration",
    "Could not update the private key password." : "Das Passwort des privaten Schlüssels konnte nicht aktualisiert werden.",
    "The old password was not correct, please try again." : "Das alte Passwort war falsch, bitte versuchen Sie es erneut.",
    "The current log-in password was not correct, please try again." : "Das aktuelle Anmeldepasswort war nicht korrekt, bitte versuchen Sie es noch einmal.",
    "Private key password successfully updated." : "Das Passwort des privaten Schlüssels wurde aktualisiert.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Falscher privater Schlüssel für die Verschlüsselungs-App. Bitte aktualisieren Sie Ihren privaten Schlüssel in Ihren persönlichen Einstellungen, um wieder Zugriff auf die verschlüsselten Dateien zu erhalten.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Verschlüsselung-App ist aktiviert, aber Ihre Schlüssel sind nicht initialisiert. Bitte melden Sie sich ab und wieder an.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Bitte aktivieren Sie die server-seitige Verschlüsselung in den Administrationseinstellungen, um das Verschlüsselungsmodul nutzen zu können.",
    "Encryption app is enabled and ready" : "Verschlüsselungs-App ist aktiviert und bereit",
    "Bad Signature" : "Falsche Signatur",
    "Missing Signature" : "Fehlende Signatur",
    "one-time password for server-side-encryption" : "Einmal-Passwort für serverseitige Verschlüsselung",
    "Encryption password" : "Verschlüsselungskennwort",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "Die Administration hat die serverseitige Verschlüsselung aktiviert. Ihre Dateien wurden mit dem Passwort <strong>%s</strong> verschlüsselt.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "Die Administration hat die serverseitige Verschlüsselung aktiviert. Ihre Dateien wurden mit dem Passwort \"%s\" verschlüsselt.",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "Bitte melden Sie sich an der Weboberfläche an, gehen Sie zum Abschnitt \"Sicherheit\" Ihrer persönlichen Einstellungen und aktualisieren Sie Ihr Verschlüsselungspasswort, indem Sie dieses Passwort in das Feld \"Altes Login-Passwort\" sowie Ihr aktuelles Login-Passwort eingeben.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Diese Datei kann nicht entschlüsselt werden, es handelt sich wahrscheinlich um eine geteilte Datei. Bitte kontaktieren Sie den Eigentümer der Datei und bitten Sie darum, die Datei noch einmal mit Ihnen zu teilen.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Diese Datei kann nicht gelesen werden, es handelt sich wahrscheinlich um eine geteilte Datei. Bitte kontaktieren Sie den Eigentümer der Datei und bitten Sie darum, die Datei noch einmal mit Ihnen zu teilen.",
    "Default encryption module" : "Standard-Verschlüsselungsmodul",
    "Default encryption module for server-side encryption" : "Standard-Verschlüsselungsmodul für serverseitige Verschlüsselung",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "Um dieses Verschlüsselungsmodul nutzen zu können, müssen Sie die serverseitige Verschlüsselung in den Administrationseinstellungen aktivieren. Sobald das Modul aktiviert ist, verschlüsselt es alle Ihre Dateien transparent. Die Verschlüsselung basiert auf AES-256-Schlüsseln.\nDas Modul ändert keine vorhandenen Dateien, nur neue Dateien werden verschlüsselt, nachdem die serverseitige Verschlüsselung aktiviert wurde. Es ist nicht möglich, die Verschlüsselung zu deaktivieren und wieder auf ein unverschlüsseltes System umzuschalten.\nBitte lesen Sie die Dokumentation, um alle Auswirkungen zu kennen, bevor Sie sich entscheiden, die serverseitige Verschlüsselung zu aktivieren.",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Verschlüsselungs-App ist aktiviert, aber die Schlüssel sind noch nicht initialisiert. Bitte melden Sie sich ab und wieder an",
    "Encrypt the home storage" : "Benutzerverzeichnis verschlüsseln",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Die Aktivierung dieser Option verschlüsselt alle Dateien die auf dem Hauptspeicher gespeichert sind, ansonsten werden nur Dateien auf dem externen Speicher verschlüsselt",
    "Enable recovery key" : "Wiederherstellungsschlüssel aktivieren",
    "Disable recovery key" : "Wiederherstellungsschlüssel deaktivieren",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Der Wiederherstellungsschlüssel ist ein zusätzlicher Verschlüsselungsschlüssel, der zum Verschlüsseln von Dateien benutzt wird. Er erlaubt die Wiederherstellung von Benutzerdateien auch dann, wenn der Benutzer sein Passwort vergessen hat.",
    "Recovery key password" : "Passwort für den Wiederherstellungsschlüssel",
    "Repeat recovery key password" : "Passwort für den Wiederherstellungsschlüssel wiederholen",
    "Change recovery key password:" : "Passwort für den Wiederherstellungsschlüssel ändern",
    "Old recovery key password" : "Altes Passwort für den Wiederherstellungsschlüssel",
    "New recovery key password" : "Neues Passwort für den Wiederherstellungsschlüssel",
    "Repeat new recovery key password" : "Neues Passwort für den Wiederherstellungsschlüssel wiederholen",
    "Change Password" : "Passwort ändern",
    "Basic encryption module" : "Basisverschlüsselungsmodul",
    "Your private key password no longer matches your log-in password." : "Das Passwort für Ihren privaten Schlüssel stimmt nicht mehr mit Ihrem Anmelde-Passwort überein.",
    "Set your old private key password to your current log-in password:" : "Ihr altes Passwort für den privaten Schlüssel auf Ihr aktuelles Anmeldepasswort setzen:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Falls Sie sich nicht an Ihr altes Passwort erinnern können, fragen Sie bitte Ihren Administrator, um Ihre Dateien wiederherzustellen.",
    "Old log-in password" : "Altes Anmelde-Passwort",
    "Current log-in password" : "Aktuelles Anmeldepasswort",
    "Update Private Key Password" : "Das Passwort des privaten Schlüssels aktualisieren",
    "Enable password recovery:" : "Die Passwort-Wiederherstellung aktivieren:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Durch die Aktivierung dieser Option haben Sie die Möglichkeit, wieder auf Ihre verschlüsselten Dateien zugreifen zu können, wenn Sie Ihr Passwort verloren haben.",
    "Enabled" : "Aktiviert",
    "Disabled" : "Deaktiviert",
    "In order to use this encryption module you need to enable server-side\n\t\tencryption in the admin settings. Once enabled this module will encrypt\n\t\tall your files transparently. The encryption is based on AES 256 keys.\n\t\tThe module won't touch existing files, only new files will be encrypted\n\t\tafter server-side encryption was enabled. It is also not possible to\n\t\tdisable the encryption again and switch back to a unencrypted system.\n\t\tPlease read the documentation to know all implications before you decide\n\t\tto enable server-side encryption." : "Zur Verwendung dieses Verschlüsselungsmoduls muss serverseitige\n\t\tVerschlüsselung in den Administrator-Einstellungen aktiviert werden. Nach der\n\t\tAktivierung werden alle Dateien verschlüsselt. Die Verschlüsselung basiert\n\t\tauf AES 256 Schlüsseln. Dieses Modul verschlüsselt nur neue Dateien,\n\t\texistierende Dateien werden nicht geändert. Es ist nicht möglich, die Ver-\n\t\tschlüsselung zu deaktivieren und zum unverschlüsselten System zurück-\n\t\tzukehren. Vor der Entscheidung, das Verschlüsselungsmodul zu verwenden,\n\t\tsollte unbedingt die Dokumentation aufmerksam gelesen werden.",
    "Hey there,\n\nThe administration enabled server-side-encryption. Your files were encrypted using the password \"%s\".\n\nPlease login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.\n\n" : "Hallo,\n\ndie Administration hat die servereitige Verschlüsselung aktiviert. Ihre Dateien wurden mit dem Passwort '%s' verschlüsselt.\n\nBitte melden Sie sich auf der Web-Oberfläche an, gehen Sie zu Ihren persönlichen Einstellungen und aktualisieren Sie dort ihr Verschlüsselungspasswort, indem Sie das Passwort in das 'altes Anmelde-Passwort' und in das 'aktuelles Anmelde-Passwort' Feld eingeben.\n\n",
    "The share will expire on %s." : "Die Freigabe wird am %s ablaufen.",
    "Cheers!" : "Noch einen schönen Tag!",
    "Hey there,<br><br>The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.<br><br>" : "Hallo,<br><br>die Administration hat die servereitige Verschlüsselung aktiviert. Die Dateien wurden mit dem Passwort <strong>%s</strong> verschlüsselt.<br><br>Bitte melden Sie sich in der Web-Oberfläche an und gehen Sie in ihre persönlichen Einstellungen. Dort finden Sie die Option 'Basisverschlüsselungsmodul' und aktualisieren Sie dort Ihr Verschlüsselungspasswort indem Sie das Passwort in das 'altes Anmelde-Passwort-' und in das 'aktuelles Anmelde-Passwort' Feld eingeben.<br><br>",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password." : "Bitte melden Sie sich an der Weboberfläche an, gehen Sie zum Abschnitt \"Sicherheit\" Ihrer persönlichen Einstellungen und aktualisieren Sie Ihr Verschlüsselungspasswort, indem Sie dieses Passwort in das Feld \"Altes Login-Passwort\" sowie Ihr aktuelles Login-Passwort eingeben."
},
"nplurals=2; plural=(n != 1);");
