OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Зададеното име е премногу долго",
    "The given web address is too long" : "Зададената веб страна е премногу долга",
    "The given web address is not a valid URL" : "Зададената веб страна нема валидна URL адреса",
    "The given legal notice address is too long" : "Зададената адреса за правно известување е премногу долга",
    "The given legal notice address is not a valid URL" : "Зададената URL адреса за правно известување не е валидна",
    "The given privacy policy address is too long" : "Зададената адреса за политика за приватност е премногу долга",
    "The given privacy policy address is not a valid URL" : "Зададената URL адреса за политика за приватност не е валидна",
    "The given slogan is too long" : "Зададениот слоган е премногу долг",
    "The given color is invalid" : "Зададената боја не е валидна",
    "Saved" : "Зачувано",
    "The file was uploaded" : "Датотеката е прикачена",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
    "The file was only partially uploaded" : "Датотеката беше само делумно прикачена",
    "No file was uploaded" : "Нема прикачено дадотека",
    "Missing a temporary folder" : "Недостасува привремена папка",
    "Could not write file to disk" : "Неможе да се запишува на дискот",
    "A PHP extension stopped the file upload" : "PHP додаток го стопираше прикачувањето на датотеката",
    "No file uploaded" : "Нема прикачено дадотека",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Веќе користите сопствена тема. Апликацијата за сопствена тема може да ја пребрише истата.",
    "Theming" : "Теми",
    "Appearance and accessibility" : "Изглед и пристапност",
    "Dark theme with high contrast mode" : "Темна тема со режим на висок контраст",
    "Enable dark high contrast mode" : "Овозможи темен режим со висок контраст",
    "Similar to the high contrast mode, but with dark colours." : "Слично на режимот со висок контраст, но со темни бои.",
    "Dark theme" : "Темна тема",
    "Enable dark theme" : "Овозможи темна тема",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Темна тема за олеснување на вашите очи со намалување на целокупниот сјај и осветленост.",
    "System default theme" : "Стандардна тема",
    "Enable the system default" : "Овозможи стандардна тема",
    "Using the default system appearance." : "Го користи стандардниот изглед.",
    "Dyslexia font" : "Фонт за дислексија",
    "Enable dyslexia font" : "Овозможи фонт за дислексија",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic е бесплатен фонт дизајниран за ублажување на некои од честите грешки во читањето предизвикани од дислексија.",
    "High contrast mode" : "Режим на висок контраст",
    "Enable high contrast mode" : "Овозможи режим на висок контраст",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Режим со висок контраст за олеснување на навигацијата. Визуелниот квалитет ќе се намали, но јасноста ќе се зголеми.",
    "Light theme" : "Светла тема",
    "Enable the default light theme" : "Овозможи стандардна светла тема",
    "The default light appearance." : "Стандарден светло изглед.",
    "Legal notice" : "Правно известување",
    "Privacy policy" : "Политика за приватност",
    "Adjust the Nextcloud theme" : "Прилагодување на темата за Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Темата овозможува можно полесно прилагодување на изгледот и чувството на вашите истанци и поддржани клиенти. Ова ќе биде видливо за сите корисници.",
    "Advanced options" : "Напредни опции",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Инсталирај ImageMagick додаток за PHP со што ќе се овозможи поддршка за SVG сликите автоматски да генерираат Фавикон базирано на прикаченото лого и боја.",
    "Name" : "Име",
    "Web link" : "Веб страна",
    "a safe home for all your data" : "безбеден дом за сите ваши податоци",
    "Slogan" : "Слоган",
    "Color" : "Боја",
    "Logo" : "Лого",
    "Upload new logo" : "Прикачи ново лого",
    "Background and login image" : "Позадина и слика на страната за најавување",
    "Upload new background and login image" : "Прикачи нова позадина и слика на страната за најавување",
    "Legal notice link" : "Правно известување",
    "Privacy policy link" : "Политика за приватност",
    "Header logo" : "Лого на заглавие",
    "Upload new header logo" : "Прикачи ново лого на заглавие",
    "Favicon" : "Фавикон",
    "Upload new favicon" : "Прикачи нов Фавикон",
    "User settings" : "Кориснички параметри",
    "Disable user theming" : "Оневозможи кориснички теми",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Иако можете да изберете и да ја прилагодите вашата истанца, корисниците можат да ја менуваат нивната позадина и бои. Ако сакате да го наметнете вашето прилагодување, можете да го вклучите ова.",
    "Background" : "Позадина",
    "Customization has been disabled by your administrator" : "Уредувањето е оневозможено од администраторот",
    "Set a custom background" : "Постави позадина",
    "Keyboard shortcuts" : "Кратенки преку тастатура",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Во некои случаи, кратенките на тастатурата може да се мешаат со алатките за пристапност. За да овозможите правилно фокусирање на вашата алатка, можете да ги оневозможите сите кратенки на тастатурата овде. Ова исто така ќе ги оневозможи сите достапни кратенки во апликациите.",
    "Disable all keyboard shortcuts" : "Оневозможи ги сите кратенки преку тастатурата",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Универзалниот пристап е многу важен за нас. Ние ги следиме веб-стандардите и ги имплементираме за да го направиме користењето попристапно, како користење без маус, и помошни апликации за читање на екранот. Наша цел е да бидеме во согласност со {guidelines} {linkend}2.1 на ниво АА, со висока контрастна тема дури и на ниво на ААА.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Доколку наидете на некој проблем, не се двоумете и пријавете го на {issuetracker} {linkend}. И доколку сакате можете да се приклучите кон нашиот {designteam} {linkend}!",
    "Custom background" : "Сопствена позадина",
    "Default background" : "Стандардна позадина",
    "Change color" : "Промени боја",
    "No background" : "Без позадина",
    "Select a background from your files" : "Избери позадина од датотеките",
    "Select background" : "Избери позадина",
    "Theme selection is enforced" : "Наметнат е избор на тема",
    "Select a custom color" : "Избери боја",
    "Reset to default" : "Ресетирај на стандардно",
    "Upload" : "Прикачи",
    "Remove background image" : "Избриши ја позадинската слика",
    "Loading preview…" : "Се вчитува прегледот...",
    "Admin" : "Администратор",
    "Error uploading the file" : "Грешка при прикачување на датотеката",
    "Name cannot be empty" : "Името неможе да биде празно",
    "Migrate and clean up admin theming images" : "Мигрирај и исчисти ги сликите со теми од администраторот",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Во некои случаи, кратенките на тастатурата може да се мешаат со алатките за пристапност. За да овозможите правилно фокусирање на вашата алатка, можете да ги оневозможите сите кратенки на тастатурата овде. Ова исто така ќе ги оневозможи сите достапни кратенки во апликациите.",
    "Pick from Files" : "Избери од датотеките",
    "Default image" : "Стандардна слика",
    "Custom color" : "Прилагодена боја",
    "Plain background" : "Обична позадина",
    "Insert from {productName}" : "Вметнни од {productName}",
    "Open documentation" : "Отвори ја документацијата",
    "https://…" : "https://…",
    "Upload new login background" : "Прикачи нова слика за позадина на најавната страница",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Иако можете да изберете и да ја прилагодите вашата истанца, корисниците можат да ја менуваат нивната позадина и бои. Ако сакате да го наметнете вашето прилагодување, можете да го штиклирате ова поле.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Инсталирај Imagemagick додаток за PHP со што ќе се овозможи поддршка за SVG сликите автоматски да генерираат Фавикон базирано на прикаченото лого и боја."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
