<?php 
$OC_Version = array(25,0,11,1);
$OC_VersionString = '25.0.11';
$OC_Edition = '';
$OC_Channel = 'stable';
$OC_VersionCanBeUpgradedFrom = array (
  'nextcloud' => 
  array (
    '24.0' => true,
    '25.0' => true,
  ),
  'owncloud' => 
  array (
    '10.11' => true,
  ),
);
$OC_Build = '2023-09-14T10:23:04+00:00 97d754dcf1aa3f166ead03a9f6a9165270c73647';
$vendor = 'nextcloud';
